diff libpurple/protocols/msn/user.h @ 16390:4fc51a87ce42

Updates for the account buddy icon stuff. This doesn't yet work fully (and maybe not even partly), but it compiles.
author Richard Laager <rlaager@wiktel.com>
date Wed, 25 Apr 2007 21:48:56 +0000
parents 32c366eeeb99
children 44b4e8bd759b 7c0a2ef88018
line wrap: on
line diff
--- a/libpurple/protocols/msn/user.h	Wed Apr 25 01:19:24 2007 +0000
+++ b/libpurple/protocols/msn/user.h	Wed Apr 25 21:48:56 2007 +0000
@@ -138,9 +138,9 @@
  * Sets the buddy icon for a local user.
  *
  * @param user     The user.
  * @param filename The path to the buddy icon.
  */
-void msn_user_set_buddy_icon(MsnUser *user, const char *filename);
+void msn_user_set_buddy_icon(MsnUser *user, PurpleStoredImage *img);
 
 /**
  * Sets the group ID list for a user.
@@ -138,9 +138,9 @@
  *
  * @param user     The user.
- * @param filename The path to the buddy icon.
+ * @param img      The buddy icon image
  */